@@ -1,17 +1,17 @@
+"""HTTP client for medical language"""
+
 from typing import List
 import os
-import logging
 import requests
 from ctakesclient.exceptions import ClientError
-from ctakesclient.typesystem import Span, Polarity
+from ctakesclient.typesystem import Polarity
 
-#######################################################################################################################
-#
-# HTTP Client for Medical Language
+###############################################################################
 #
 # https://github.com/Machine-Learning-for-Medical-Language/cnlp_transformers#negation-api
 #
-#######################################################################################################################
+###############################################################################
+
 
 def get_url_cnlp_negation() -> str:
     """
@@ -19,9 +19,12 @@ def get_url_cnlp_negation() -> str:
 
     :return: CTAKES_URL_NEGATION env variable or default using localhost
     """
-    return os.environ.get('URL_CNLP_NEGATION', 'http://localhost:8000/negation/process')
+    return os.environ.get('URL_CNLP_NEGATION',
+                          'http://localhost:8000/negation/process')
 
-def list_polarity(sentence: str, spans: list, url=get_url_cnlp_negation()) -> List[Polarity]:
+
+def list_polarity(sentence: str, spans: list,
+                  url=get_url_cnlp_negation()) -> List[Polarity]:
     """
     :param sentence: clinical text to send to cTAKES
     :param spans: list of spans where each span is a tuple of (begin,end)
@@ -30,8 +33,9 @@ def list_polarity(sentence: str, spans: list, url=get_url_cnlp_negation()) -> Li
     """
     doc = {'doc_text': sentence, 'entities': spans}
 
-    response = requests.post(url=url, json=doc).json()
-    polarities = list()
+    # TODO: consider exposing a pass-through timeout parameter
+    response = requests.post(url=url, json=doc).json()  # pylint: disable=missing-timeout
+    polarities = []
 
     for status in response['statuses']:
         # NOT negated (double negative)
@@ -44,11 +48,14 @@ def list_polarity(sentence: str, spans: list, url=get_url_cnlp_negation()) -> Li
             raise ClientError(f'negate-api unknown {status}, url= {url}')
 
     if len(spans) != len(polarities):
-        raise ClientError(f'Number of Spans and Polarities did not match: {spans}, {polarities}')
+        raise ClientError('Number of Spans and Polarities did not match: '
+                          f'{spans}, {polarities}')
 
     return polarities
 
-def map_polarity(sentence: str, spans: list, url=get_url_cnlp_negation()) -> dict:
+
+def map_polarity(sentence: str, spans: list,
+                 url=get_url_cnlp_negation()) -> dict:
     """
     :param sentence: clinical text to send to cTAKES
     :param spans: list of spans where each span is a tuple of (begin,end)
@@ -56,7 +63,7 @@ def map_polarity(sentence: str, spans: list, url=get_url_cnlp_negation()) -> dic
     :return: Map of Polarity key=span, value=polarity
     """
     polarities = list_polarity(sentence, spans, url)
-    mapped = dict()
+    mapped = {}
 
     for span, polarity in zip(spans, polarities):
         mapped[span] = polarity
